#coding:utf-8

import pygame
import time
from board import SCL, SDA
import busio

from adafruit_pca9685 import PCA9685
from adafruit_motor import servo

i2c = busio.I2C(SCL, SDA)
pca = PCA9685(i2c, address=0x41)
pca.frequency = 50

#定义显示颜色
BLACK = pygame.Color('black')
WHITE = pygame.Color('white')

import RPi.GPIO as GPIO
pin = 18

GPIO.setmode(GPIO.BCM)      ##此处采用的BCM编码 因为T型扩展板也是BCM编码 方便统一
GPIO.setup(pin, GPIO.OUT)   ##设置BCM编码下18号引脚为输出状态
GPIO.output(pin, GPIO.LOW)  ##由于跳线帽设置高电平出发，因此低电平关灯


#信息输出类
class TextPrint():
    def __init__(self):
        self.reset()
        self.font = pygame.font.Font(None, 20)

    def tprint(self, screen, textString):
        textBitmap = self.font.render(textString, True, BLACK)
        screen.blit(textBitmap, (self.x, self.y))
        self.y += self.line_height

    def reset(self):
        self.x = 10
        self.y = 10
        self.line_height = 15
    def indent(self):
        self.x += 10

    def unindent(self):
        self.x -= 10

pygame.init()
screen = pygame.display.set_mode((500, 700))
pygame.display.set_caption("My Game")
done = False
clock = pygame.time.Clock()

#初始化joystick
pygame.joystick.init()
textPrint = TextPrint()

#主程序
while not done:
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            done = True #停止
        elif event.type == pygame.JOYBUTTONDOWN:
            print('joystick button pressed!')
        elif event.type == pygame.JOYBUTTONUP:
            print('joystick button released!')


    #绘图
    screen.fill(WHITE)
    textPrint.reset()

    #获取摇杆数量
    joystick_count = pygame.joystick.get_count()

    #数量信息输出
    textPrint.tprint(screen, "number of joysticks: {}".format(joystick_count))
    textPrint.indent()

    #逐个遍历按钮和摇杆
    for i in range(joystick_count):
        joystick = pygame.joystick.Joystick(i)  #创建对象
        joystick.init()

        try:
            jid = joystick.get_instance_id()
        except AttributeError:
            jid = joystick.get_id
        textPrint.tprint(screen, "Joystick {}".format(jid))
        textPrint.indent()

        #获取名称
        name = joystick.get_name()
        textPrint.tprint(screen, "Joystick name: {}".format(name))

        try:
            guid = joystick.get_guid()
        except AttributeError:
            pass
        else:
            textPrint.tprint(screen, "GUID: {}".format(guid))

        #获取操作杆轴数
        axes = joystick.get_numaxes()
        textPrint.tprint(screen, "Number of axes:{}".format(axes))

        #获取每个轴的数值
        for i in range(axes):
            axis = joystick.get_axis(i) #获取每个轴当前的位置 数字表示 取件-1到1之间 0表示居中

            if (i==5):
                print(axis)
                if axis>0:
                    GPIO.output(pin, GPIO.HIGH)
                else:
                    GPIO.output(pin, GPIO.LOW)


            if (i==3):
                servo7 = servo.Servo(pca.channels[0])
                servo7.set_pulse_width_range(min_pulse=500, max_pulse=2500)

                print(axis)
                if axis > 0:
                    servo7.angle = 10

                elif axis < 0:
                    servo7.angle = 170

                else:
                    servo7.angle = 90


            textPrint.tprint(screen, "Axis {} value is:{:>6.3f}".format(i, axis))
        textPrint.unindent()

        #获取手柄按钮数据
        buttons = joystick.get_numbuttons()
        textPrint.tprint(screen, "Number of buttons:{}".format(buttons))
        textPrint.indent()

        #获取每个按钮状态
        for i in range(buttons):
            button = joystick.get_button(i) #获取当前按钮状态 按压True 否False
            textPrint.tprint(screen, "button {:>2} value {}".format(i, button))
        textPrint.unindent()
        #获取方向键状态
        hats = joystick.get_numhats()  #获取数量
        textPrint.tprint(screen, "Number of hats:{}".format(hats))
        textPrint.indent()

        #获取每个按键的值
        for i in range(hats):
            hat = joystick.get_hat(i)
            textPrint.tprint(screen, "Hat {} value: {}".format(i, str(hat)))
        textPrint.unindent()
        textPrint.unindent()
    pygame.display.flip()
    clock.tick(20)

pygame.quit()